# python-utils
Common python utilities, currently for Build scripts

## pykrete
Python package for import in Build scripts:  
pykrete  
|-- args - argument types verifiers  
|-- builder - build management  
| . |-- info - build information  
| . |-- manager - build managers  
|-- calls - shell calls  
|-- ci - manage Continuous Integration  
|-- credentials - manage access credentials  
|-- distrib - distutils commands  
| . |-- pylint - pylint commands  
|-- lgging - logging helpers  
|-- packages - package management   
|-- patterns - Design patterns bases  
| . |-- visitor - Visitor pattern bases  
|-- repo - repository management  
|-- versioning - version management
